// main包是Go程序的入口包，每个可执行程序必须包含一个main包
package main

// 导入fmt包，用于格式化输入输出
import "fmt"

// main函数是程序执行的入口点
func main() {
	// 基本数据类型示例
	// 使用var关键字声明多个变量，可以分组声明
	var (
		// int类型表示整数，默认是32位或64位取决于平台
		integer int = 42
		// float64表示64位浮点数(双精度浮点数)
		float float64 = 3.14
		// bool类型表示布尔值，只有true或false两个值
		boolean bool = true
		// string类型表示字符串，使用双引号包裹
		str string = "Hello"
	)

	// 复合类型示例
	// array是固定长度的数组，类型为[3]int表示包含3个int元素的数组
	var array [3]int = [3]int{1, 2, 3}
	// slice是动态数组，使用:=短变量声明方式初始化
	slice := []string{"a", "b", "c"}

	// 打印数据类型示例
	fmt.Println("数据类型示例:")
	// 使用fmt.Printf格式化输出:
	// %d - 整数, %f - 浮点数, %t - 布尔值, %s - 字符串
	fmt.Printf("integer: %d, float: %f, boolean: %t, string: %s\n",
		integer, float, boolean, str)
	// %v - 通用格式，可以打印任何类型的值
	fmt.Printf("array: %v, slice: %v\n", array, slice)

	// map是键值对集合，这里声明一个string到int的映射
	var mapExample map[string]int = map[string]int{
		"one": 1, // 键"one"对应值1
		"two": 2, // 键"two"对应值2
	}

	// 从map中获取键"one"对应的值
	exo := mapExample["one"]
	// 打印map和从map中获取的值
	fmt.Printf("mapExample: %v, mapExample[\"one\"]: %d\n", mapExample, exo)
}
