package main

import (
	"fmt"
	"math"
)

// 判断一个数是否为素数
func isPrime(n int) bool {
	if n <= 1 {
		return false
	}
	sqrt := int(math.Sqrt(float64(n)))
	for i := 2; i <= sqrt; i++ {
		if n%i == 0 {
			return false
		}
	}
	return true
}

func worker(id int, jobs <-chan int, results chan<- int) {
	for job := range jobs {
		fmt.Printf("Worker %d processing job %d\n", id, job)
		// 计算从job开始的前100个数中有多少个素数
		count := 0
		for i := job; i < job+100; i++ {
			if isPrime(i) {
				count++
			}
		}
		results <- count // 将结果发送到results通道
	}
}

func main() {
	jobs := make(chan int, 100)    // 工作通道
	results := make(chan int, 100) // 结果通道

	// 启动3个工作协程
	for w := 1; w <= 3; w++ {
		go worker(w, jobs, results)
	}

	// 发送工作任务
	for j := 1; j <= 80; j++ {
		jobs <- j
	}
	close(jobs)

	// 收集结果
	for i := 1; i <= 80; i++ {
		result := <-results
		fmt.Printf("Got result: %d\n", result) // 输出每个范围内的素数个数
	}
}
